@@ -1,7 +1,7 @@
 #! /usr/bin/env python3
 
 """
-Name That Hash: Name the hash type.
+pywhat: Identify Anything.
 """
 
 import sys
