@@ -1,4 +1,5 @@
 import json
+
 from rich.console import Console
 from rich.table import Table
 
@@ -29,11 +30,12 @@ class Printing:
             to_out += f"[bold #D7Afff]File Identified[/bold #D7Afff] with Magic Numbers {text['File Signatures']['ISO 8859-1']}."
             to_out += f"\n[bold #D7Afff]File Description:[/bold #D7Afff] {text['File Signatures']['Description']}."
             to_out += "\n"
-        console.print(to_out)
+        if to_out:
+            console.print(to_out)
         to_out = ""
 
-        if text["Regexes"] and len(text["Regexes"]):
-            to_out += f"\n[bold #D7Afff]Possible Identification[/bold #D7Afff]"
+        if text["Regexes"]:
+            to_out += "\n[bold #D7Afff]Possible Identification[/bold #D7Afff]"
             table = Table(
                 show_header=True, header_style="bold #D7Afff", show_lines=True
             )
@@ -41,8 +43,8 @@ class Printing:
             table.add_column("Identified as")
             table.add_column("Description")
             for i in text["Regexes"]:
-                matched = i["Matched"]
-                name = i["Regex Pattern"]["Name"]
+                matched = str(i["Matched"])
+                name = str(i["Regex Pattern"]["Name"])
                 description = self.get_crypto_links(name, matched)
                 if not description:
                     description = i["Regex Pattern"]["Description"]
@@ -52,8 +54,11 @@ class Printing:
                     description,
                 )
             console.print(to_out, table)
-        if text["Hashes"] and len(text["Hashes"]) > 1:
-            to_out = f"\n[bold #D7Afff]Hashes Identified[/bold #D7Afff]"
+        """
+        # This is commented out because there's too many possible hash idenfications
+        # This is fixed by https://github.com/HashPals/Name-That-Hash/issues/89
+        if text["Hashes"]:
+            to_out = "\n[bold #D7Afff]Hashes Identified[/bold #D7Afff]"
             table = Table(
                 show_header=True, header_style="bold #D7Afff", show_lines=True
             )
@@ -68,6 +73,7 @@ class Printing:
                         types["description"],
                     )
             console.print(to_out, table)
+        """
 
     def print_json(self, text: dict):
         return json.dumps(text, indent=4)
@@ -78,6 +84,7 @@ class Printing:
             "Dogecoin Wallet Address": "https://dogechain.info/address/",
             "Bitcoin Wallet": "https://www.blockchain.com/btc/address/",
             "YouTube Video ID": "https://www.youtube.com/watch?v=",
+            "YouTube Channel ID": "https://www.youtube.com/channel/",
         }
         if text in explorers:
             return "Click here to analyse in the browser " + explorers[text] + matched
