@@ -1,6 +1,5 @@
 import click
-from pywhat import identifier
-from pywhat import printer
+from pywhat import identifier, printer
 
 
 @click.command()
